@@ -1,6 +1,6 @@
 <?php
 
-global $username;
+global $username, $cq_quota_binary, $cq_use_1000KB_per_MB;
 
 exec("$cq_quota_binary -v $username", $quota_data, $return_data);
 
@@ -11,9 +11,9 @@ if ( sizeof($quota_data) > 2 ) {
 		list($cq_fsname, $cq_taken, $cq_total, $cq_limit) =
 			split( "[[:blank:]]+", trim($quota_data[$i]) );
 
-		if ( strlen($cq_fsname) != 0 && strlen($cq_taken) == 0 && strlen($cq_quota) == 0 )
+		if ( strlen($cq_fsname) != 0 && strlen($cq_taken) == 0 && strlen($cq_total) == 0 )
 		{
- 			list($cq_taken, $cq_quota, $cq_limit) =
+ 			list($cq_taken, $cq_total, $cq_limit) =
 				split( "[[:blank:]]+", trim($quota_data[$i+1]) );
 			$i++;
 		}
@@ -97,9 +97,9 @@ if ( sizeof($quota_data) > 2 ) {
 					$cq_t_unit = "KB";
 			}
 
-			if ( $fn_left == 1 )
+			if ( isset($fn_left) && $fn_left == 1 )
 				include("show_graph.php");
-			if ( $fn_motd == 1 )
+			if ( isset($fn_motd) && $fn_motd == 1 )
 				include("show_motd.php");
 
 			$cq_size_quota = FALSE;
@@ -108,12 +108,12 @@ if ( sizeof($quota_data) > 2 ) {
 
 	for ( $i=2 ; $i<sizeof($quota_data) ; $i++ )
 	{
-		list($cq_fsname, $cq_taken, $cq_total, $cq_limit, $cq_grace, $cq_count, $cq_maxcount, $cq_countlimit) =
+		list($cq_fsname, $cq_taken2, $cq_total2, $cq_limit, $cq_grace, $cq_count, $cq_maxcount, $cq_countlimit) =
 			split( "[[:blank:]]+", trim($quota_data[$i]) );
 
-		if ( strlen($cq_fsname) != 0 && strlen($cq_taken) == 0 && strlen($cq_quota) == 0 )
+		if ( strlen($cq_fsname) != 0 && strlen($cq_taken2) == 0 && strlen($cq_total2) == 0 )
 		{
- 			list($cq_taken, $cq_total, $cq_limit, $cq_grace, $cq_count, $cq_maxcount, $cq_countlimit) =
+ 			list($cq_taken2, $cq_total2, $cq_limit, $cq_grace, $cq_count, $cq_maxcount, $cq_countlimit) =
 				split( "[[:blank:]]+", trim($quota_data[$i+1]) );
 			$i++;
 		}
@@ -144,9 +144,9 @@ if ( sizeof($quota_data) > 2 ) {
 
 			$cq_countpercent = number_format(($cq_count / $cq_maxcount) * 100, 1);
 
-			if ( $fn_left == 1 )
+			if ( isset($fn_left) && $fn_left == 1 )
 				include("show_graph.php");
-			if ( $fn_motd == 1 )
+			if ( isset($fn_motd) && $fn_motd == 1 )
 				include("show_motd.php");
 
 			$cq_count_quota = FALSE;
