@@ -1,9 +1,14 @@
 <?php
 
+if ( !defined('SM_PATH') ) {
+    define('SM_PATH', '../../');
+}
+
+include_once(SM_PATH . "plugins/check_quota/config.php");
+
 function squirrelmail_plugin_init_check_quota() {
-  include("config.php");
-  global $squirrelmail_plugin_hooks;
-  if ( $cq_show_above_folders_list )
+  global $squirrelmail_plugin_hooks, $cq_show_above_folders_list;
+  if ( isset($cq_show_above_folders_list) && $cq_show_above_folders_list )
     $squirrelmail_plugin_hooks['left_main_before']['check_quota'] = 'check_quota_left_do';
   else
     $squirrelmail_plugin_hooks['left_main_after']['check_quota'] = 'check_quota_left_do';
@@ -11,11 +16,7 @@ function squirrelmail_plugin_init_check_quota() {
 }
 
 function check_quota_version() {
-    return '1.2';
-}
-
-if ( !defined('SM_PATH') ) {
-    define('SM_PATH', '../../');
+    return '1.3';
 }
 
 include_once("functions.php");
